==> zio-aws-ec2_2.13-5.17.102.9-sources.jar: zio/aws/ec2/model/GetDefaultCreditSpecificationResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetDefaultCreditSpecificationResponse(
    instanceFamilyCreditSpecification: Option[
      zio.aws.ec2.model.InstanceFamilyCreditSpecification
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse = {
    import GetDefaultCreditSpecificationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse
      .builder()
      .optionallyWith(
        instanceFamilyCreditSpecification.map(value => value.buildAwsValue())
      )(_.instanceFamilyCreditSpecification)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetDefaultCreditSpecificationResponse.ReadOnly =
    zio.aws.ec2.model.GetDefaultCreditSpecificationResponse
      .wrap(buildAwsValue())
}
object GetDefaultCreditSpecificationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetDefaultCreditSpecificationResponse =
      zio.aws.ec2.model.GetDefaultCreditSpecificationResponse(
        instanceFamilyCreditSpecification.map(value => value.asEditable)
      )
    def instanceFamilyCreditSpecification
        : Option[zio.aws.ec2.model.InstanceFamilyCreditSpecification.ReadOnly]
    def getInstanceFamilyCreditSpecification: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.InstanceFamilyCreditSpecification.ReadOnly
    ] = AwsError.unwrapOptionField(
      "instanceFamilyCreditSpecification",
      instanceFamilyCreditSpecification
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse
  ) extends zio.aws.ec2.model.GetDefaultCreditSpecificationResponse.ReadOnly {
    override val instanceFamilyCreditSpecification
        : Option[zio.aws.ec2.model.InstanceFamilyCreditSpecification.ReadOnly] =
      scala
        .Option(impl.instanceFamilyCreditSpecification())
        .map(value =>
          zio.aws.ec2.model.InstanceFamilyCreditSpecification.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse
  ): zio.aws.ec2.model.GetDefaultCreditSpecificationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.163.1-sources.jar: zio/aws/ec2/model/GetDefaultCreditSpecificationResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetDefaultCreditSpecificationResponse(
    instanceFamilyCreditSpecification: Optional[
      zio.aws.ec2.model.InstanceFamilyCreditSpecification
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse = {
    import GetDefaultCreditSpecificationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse
      .builder()
      .optionallyWith(
        instanceFamilyCreditSpecification.map(value => value.buildAwsValue())
      )(_.instanceFamilyCreditSpecification)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetDefaultCreditSpecificationResponse.ReadOnly =
    zio.aws.ec2.model.GetDefaultCreditSpecificationResponse
      .wrap(buildAwsValue())
}
object GetDefaultCreditSpecificationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetDefaultCreditSpecificationResponse =
      zio.aws.ec2.model.GetDefaultCreditSpecificationResponse(
        instanceFamilyCreditSpecification.map(value => value.asEditable)
      )
    def instanceFamilyCreditSpecification
        : Optional[zio.aws.ec2.model.InstanceFamilyCreditSpecification.ReadOnly]
    def getInstanceFamilyCreditSpecification: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.InstanceFamilyCreditSpecification.ReadOnly
    ] = AwsError.unwrapOptionField(
      "instanceFamilyCreditSpecification",
      instanceFamilyCreditSpecification
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse
  ) extends zio.aws.ec2.model.GetDefaultCreditSpecificationResponse.ReadOnly {
    override val instanceFamilyCreditSpecification: Optional[
      zio.aws.ec2.model.InstanceFamilyCreditSpecification.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceFamilyCreditSpecification())
      .map(value =>
        zio.aws.ec2.model.InstanceFamilyCreditSpecification.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetDefaultCreditSpecificationResponse
  ): zio.aws.ec2.model.GetDefaultCreditSpecificationResponse.ReadOnly =
    new Wrapper(impl)
}
